@@ -42,7 +42,7 @@ fn _shakmaty(fen: &str) {
     let pos: Chess = fen
         .parse::<Fen>()
         .unwrap()
-        .position(CastlingMode::Standard)
+        .into_position(CastlingMode::Standard)
         .unwrap();
     let shakmaty_start = Instant::now();
     let shakmaty_depth = 6;
@@ -81,6 +81,6 @@ fn main() {
         "q7/4kr2/8/2b4n/4K3/6N1/1R1QB3/8 w - - 0 1",
     ] {
         retroboard(fen);
-        //shakmaty(fen);
+        _shakmaty(fen);
     }
 }
